==> igniteui-webcomponents-layouts-4.3.2.tgz: package/esm2015/lib/igc-tool-action-separator-component.js <==
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionSeparator } from "./ToolActionSeparator";
import { getAllPropertyNames, toSpinal, ensureBool } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionSeparatorComponent = /*@__PURE__*/ (() => {
    class IgcToolActionSeparatorComponent extends IgcToolActionComponent {
        createImplementation() {
            return new ToolActionSeparator();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent == null) {
                let names = getAllPropertyNames(IgcToolActionSeparatorComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent = names;
            }
            return IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent;
        }
        static register() {
            if (!IgcToolActionSeparatorComponent._isElementRegistered) {
                IgcToolActionSeparatorComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionSeparatorComponent.htmlTagName, IgcToolActionSeparatorComponent);
            }
        }
        /**
         * Gets or sets the size of the separator.
        */
        get size() {
            return this.i.e5;
        }
        set size(v) {
            this.i.e5 = +v;
            this._a("size", this.i.e5);
        }
        /**
         * Gets or sets whether to use group header styling or regular styling on this separator.
        */
        get isGroupHeaderSeparator() {
            return this.i.e3;
        }
        set isGroupHeaderSeparator(v) {
            this.i.e3 = ensureBool(v);
            this._a("isGroupHeaderSeparator", this.i.e3);
        }
        fromInfo(info) {
            this.i.dp(info);
        }
    }
    IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent = null;
    IgcToolActionSeparatorComponent.htmlTagName = "igc-tool-action-separator";
    IgcToolActionSeparatorComponent._isElementRegistered = false;
    return IgcToolActionSeparatorComponent;
})();

==> igniteui-webcomponents-layouts-5.0.1.tgz: package/esm2015/lib/igc-tool-action-separator-component.js <==
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionSeparator } from "./ToolActionSeparator";
import { getAllPropertyNames, toSpinal, ensureBool } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionSeparatorComponent = /*@__PURE__*/ (() => {
    class IgcToolActionSeparatorComponent extends IgcToolActionComponent {
        createImplementation() {
            return new ToolActionSeparator();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent == null) {
                let names = getAllPropertyNames(IgcToolActionSeparatorComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent = names;
            }
            return IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent;
        }
        static register() {
            if (!IgcToolActionSeparatorComponent._isElementRegistered) {
                IgcToolActionSeparatorComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionSeparatorComponent.htmlTagName, IgcToolActionSeparatorComponent);
            }
        }
        /**
         * Gets or sets the size of the separator.
        */
        get size() {
            return this.i.hd;
        }
        set size(v) {
            this.i.hd = +v;
            this._a("size", this.i.hd);
        }
        /**
         * Gets or sets whether to use group header styling or regular styling on this separator.
        */
        get isGroupHeaderSeparator() {
            return this.i.hb;
        }
        set isGroupHeaderSeparator(v) {
            this.i.hb = ensureBool(v);
            this._a("isGroupHeaderSeparator", this.i.hb);
        }
    }
    IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent = null;
    IgcToolActionSeparatorComponent.htmlTagName = "igc-tool-action-separator";
    IgcToolActionSeparatorComponent._isElementRegistered = false;
    return IgcToolActionSeparatorComponent;
})();
